@@ -27,14 +27,13 @@ use Moose;
 use namespace::autoclean;
 use File::HomeDir;
 use YAML ();
+use SDL;
+use SDL::Joystick;
 
 my $IS_SDL_INIT_DONE = 0;
-######
-# NOTE: Need to be able to safely load this module without having SDL installed
-######
 
 use constant MAX_AXIS_INT      => 32768;
-use constant MIN_AXIS_INT      => -32767;
+use constant MIN_AXIS_INT      => -32768;
 use constant EVENT_NAME        => 'uav_pilot_sdl_joystick';
 use constant DEFAULT_CONF_FILE => 'sdl_joystick.yml';
 use constant DEFAULT_CONF      => {
@@ -272,12 +271,7 @@ sub _one_time_init
 {
     return 1 if $IS_SDL_INIT_DONE;
 
-    eval <<END;
-        use SDL;
-        use SDL::Joystick;
-        SDL::init_sub_system( SDL_INIT_JOYSTICK );
-END
-    die "Could not init SDL::Joystick: $@" if $@;
+    SDL::init_sub_system( SDL_INIT_JOYSTICK );
 
     $IS_SDL_INIT_DONE = 1;
     return 1;
@@ -296,9 +290,16 @@ __END__
 =head1 SYNOPSIS
 
     my $condvar = AnyEvent->condvar;
-    my $events = UAV::Pilot::EasyEvent->new({
+    my $event = UAV::Pilot::Events->new({
         condvar => $condvar,
     });
+    my $easy_event = UAV::Pilot::EasyEvent->new({
+        condvar => $condvar,
+    });
+    my $sdl_events = UAV::Pilot::SDL::Events->new({
+        condvar => $condvar,
+    });
+    $events->register( $sdl_events );
     
     my $control = UAV::Pilot::Controller::ARDrone->new( ... );
     my $joy = UAV::Pilot::SDL::Joystick->new({
@@ -306,11 +307,7 @@ __END__
         events     => $events,
         conf_path  => '/path/to/config.yml', # optional
     });
-    
-    my $sdl_events = UAV::Pilot::SDL::Events->new({
-        condvar    => $condvar,
-    });
-    $sdl_events->register( $joy );
+    $events->register( $joy );
 
     # Capture joystick movements in EasyEvent
     $events->add_event( UAV::Pilot::SDL::Joystick->EVENT_NAME, sub {
